@@ -1,9 +1,9 @@
 use std::{error::Error, str::FromStr};
 
 use chrono::Duration;
-use teloxide::{prelude2::*, types::ChatPermissions, utils::command::BotCommand};
+use teloxide::{prelude::*, types::ChatPermissions, utils::command::BotCommands};
 
-// Derive BotCommand to parse text with a command into this enumeration.
+// Derive BotCommands to parse text with a command into this enumeration.
 //
 //  1. rename = "lowercase" turns all the commands into lowercase letters.
 //  2. `description = "..."` specifies a text before all the commands.
@@ -12,7 +12,7 @@ use teloxide::{prelude2::*, types::ChatPermissions, utils::command::BotCommand};
 // your commands in this format:
 // %GENERAL-DESCRIPTION%
 // %PREFIX%%COMMAND% - %DESCRIPTION%
-#[derive(BotCommand, Clone)]
+#[derive(BotCommands, Clone)]
 #[command(
     rename = "lowercase",
     description = "Use commands in format /%command% %num% %unit%",
@@ -53,17 +53,35 @@ impl FromStr for UnitOfTime {
     }
 }
 
-// Calculates time of user restriction.
-fn calc_restrict_time(time: u64, unit: UnitOfTime) -> Duration {
-    match unit {
-        UnitOfTime::Hours => Duration::hours(time as i64),
-        UnitOfTime::Minutes => Duration::minutes(time as i64),
-        UnitOfTime::Seconds => Duration::seconds(time as i64),
-    }
+#[tokio::main]
+async fn main() {
+    pretty_env_logger::init();
+    log::info!("Starting admin_bot...");
+
+    let bot = teloxide::Bot::from_env().auto_send();
+
+    teloxide::commands_repl(bot, action, Command::ty()).await;
 }
 
 type Bot = AutoSend<teloxide::Bot>;
 
+async fn action(
+    bot: Bot,
+    msg: Message,
+    command: Command,
+) -> Result<(), Box<dyn Error + Send + Sync>> {
+    match command {
+        Command::Help => {
+            bot.send_message(msg.chat.id, Command::descriptions().to_string()).await?;
+        }
+        Command::Kick => kick_user(bot, msg).await?,
+        Command::Ban { time, unit } => ban_user(bot, msg, calc_restrict_time(time, unit)).await?,
+        Command::Mute { time, unit } => mute_user(bot, msg, calc_restrict_time(time, unit)).await?,
+    };
+
+    Ok(())
+}
+
 // Kick a user with a replied message.
 async fn kick_user(bot: Bot, msg: Message) -> Result<(), Box<dyn Error + Send + Sync>> {
     match msg.reply_to_message() {
@@ -78,6 +96,29 @@ async fn kick_user(bot: Bot, msg: Message) -> Result<(), Box<dyn Error + Send +
     Ok(())
 }
 
+// Ban a user with replied message.
+async fn ban_user(
+    bot: Bot,
+    msg: Message,
+    time: Duration,
+) -> Result<(), Box<dyn Error + Send + Sync>> {
+    match msg.reply_to_message() {
+        Some(replied) => {
+            bot.kick_chat_member(
+                msg.chat.id,
+                replied.from().expect("Must be MessageKind::Common").id,
+            )
+            .until_date(msg.date + time)
+            .await?;
+        }
+        None => {
+            bot.send_message(msg.chat.id, "Use this command in a reply to another message!")
+                .await?;
+        }
+    }
+    Ok(())
+}
+
 // Mute a user with a replied message.
 async fn mute_user(
     bot: Bot,
@@ -102,52 +143,11 @@ async fn mute_user(
     Ok(())
 }
 
-// Ban a user with replied message.
-async fn ban_user(
-    bot: Bot,
-    msg: Message,
-    time: Duration,
-) -> Result<(), Box<dyn Error + Send + Sync>> {
-    match msg.reply_to_message() {
-        Some(replied) => {
-            bot.kick_chat_member(
-                msg.chat.id,
-                replied.from().expect("Must be MessageKind::Common").id,
-            )
-            .until_date(msg.date + time)
-            .await?;
-        }
-        None => {
-            bot.send_message(msg.chat.id, "Use this command in a reply to another message!")
-                .await?;
-        }
+// Calculates time of user restriction.
+fn calc_restrict_time(time: u64, unit: UnitOfTime) -> Duration {
+    match unit {
+        UnitOfTime::Hours => Duration::hours(time as i64),
+        UnitOfTime::Minutes => Duration::minutes(time as i64),
+        UnitOfTime::Seconds => Duration::seconds(time as i64),
     }
-    Ok(())
-}
-
-async fn action(
-    bot: Bot,
-    msg: Message,
-    command: Command,
-) -> Result<(), Box<dyn Error + Send + Sync>> {
-    match command {
-        Command::Help => {
-            bot.send_message(msg.chat.id, Command::descriptions()).await?;
-        }
-        Command::Kick => kick_user(bot, msg).await?,
-        Command::Ban { time, unit } => ban_user(bot, msg, calc_restrict_time(time, unit)).await?,
-        Command::Mute { time, unit } => mute_user(bot, msg, calc_restrict_time(time, unit)).await?,
-    };
-
-    Ok(())
-}
-
-#[tokio::main]
-async fn main() {
-    pretty_env_logger::init();
-    log::info!("Starting admin_bot...");
-
-    let bot = teloxide::Bot::from_env().auto_send();
-
-    teloxide::repls2::commands_repl(bot, action, Command::ty()).await;
 }
